@@ -26,6 +26,7 @@ void	BeepSend (char callsign[], char flag)
 	char	buff[12], flags[3];
 	char	msg[20];
 	char	len;
+	char	status;
 
 		switch (flag)
 		{
@@ -54,7 +55,7 @@ void	BeepSend (char callsign[], char flag)
 		while (1)
 		{
 		   	usb_control_msg(udev, 0xC0, GET_REMAINSPACE, 0, 0, &len ,1, 100);
-			if (len >=95)
+			if (len >= 95)
 			{
 				usb_control_msg(udev, 0x40, SET_PTT, ON, 0, buff, 0, 100);
 				PTT_On = TRUE;
@@ -133,6 +134,13 @@ void	BeepSend (char callsign[], char flag)
 
 		/* PTT OFF */
 		usb_control_msg(udev, 0x40, SET_PTT, OFF, 0, buff, 0, 100);
+
+		while(1)
+		{
+			usb_control_msg (udev, 0xC0, GET_AD_STATUS, 0, 0, &status, 1, 100);
+			if (!(status & PTT_OnOff)) break;
+			usleep (200000);
+		}
 		PTT_On = FALSE;
 }
 
