@@ -19,11 +19,15 @@
 	2014.02.06 V00.13 Bug fixed
 	2014.02.06 V00.14 Added KeepAlive for TCP
 	2014.02.07 V00.15 Changed hole punching interval
+	2014.02.12 V00.16 Changed Busy logic
+	2014.02.13 V00.17 Changed Busy logic
+	2014.02.14 V00.18 Changed Hole Punching packet format
 */
 
-#include "dsgwd_pi.h"
-#include "version.h"
-#include "node.h"
+#include	"dsgwd_pi.h"
+#include	"version.h"
+#include	"node.h"
+#include	"holeP.h"
 
 void	*node_adapter (void *arg);
 void	send_dsvt(void);
@@ -62,6 +66,7 @@ char	RelaySW;
 char	respFlags;
 char	Connected;
 char	DVwait;
+char	AckSW;
 unsigned char	SndPacketIdSave[2];
 unsigned char	RcvPacketIdSave[2];
 
@@ -168,6 +173,7 @@ void	send_dsvt(void)
 				ConnectWait = FALSE;
 				FirstHeaderSend = FALSE;
 				Connected = FALSE;
+				AckSW = FALSE;
 			}
 		}
 	}
@@ -181,14 +187,14 @@ void	receive_dsvt(void)
 	addrlen = sizeof(struct sockaddr_in);
 	recvfrom (udpSocket, (char *)&inet_recv, sizeof(inet_recv), 0, 
 		(struct sockaddr *)&sndAddr, &addrlen);
-        if (memcmp ((char *)&inet_recv, "\0\0\0\0SRCREQ", 10) == 0)
+        if (memcmp ((char *)&inet_recv, SRCREQ, 5) == 0)
         {
-		sendto (udpSocket, "\0\0\0\0SRCACK UDP hole punching", 28, 0,
+		sendto (udpSocket, SRCACK, 5, 0,
                		(struct sockaddr *)&sndAddr, sizeof(sndAddr));
         }
-        if (memcmp ((char *)&inet_recv, "\0\0\0\0DSTREQ", 10) == 0)
+        if (memcmp ((char *)&inet_recv, DSTREQ, 5) == 0)
         {
-		if (!Connected)
+		if (!Connected && AckSW)
 		{	
                 	ConnectWait = FALSE;
                 	FirstHeaderSend = TRUE;
@@ -197,9 +203,9 @@ void	receive_dsvt(void)
 			Connected = TRUE;
 		}
         }
-        if (memcmp ((char *)&inet_recv, "\0\0\0\0SRCACK", 10) == 0)
+        if (memcmp ((char *)&inet_recv, SRCACK, 5) == 0)
         {
-		if (!Connected)
+		if (!Connected && AckSW)
 		{
 			dstPort = sndAddr.sin_port;
 			dstIP = sndAddr.sin_addr;
@@ -230,7 +236,6 @@ void	AckSendTrust(char srcRptCall[], char PacketID[] )
         ack_msg.PacketID[1] = PacketID[1];
         sendto (udpSocket, (char *)&ack_msg, sizeof(ack_msg), 0,
                  (struct sockaddr *)&sndAddr, sizeof(sndAddr));
-	return;
 }
 
 void    NakSendTrust(char srcRptCall[], char PacketID[])
@@ -248,7 +253,6 @@ void    NakSendTrust(char srcRptCall[], char PacketID[])
 	
         sendto (udpSocket, (char *)&ack_msg, sizeof(ack_msg), 0,
                  (struct sockaddr *)&sndAddr, sizeof(sndAddr));
-        return;
 }
 
 void	ReqSendSender()
@@ -256,7 +260,7 @@ void	ReqSendSender()
 	sndAddr.sin_family = PF_INET;
 	sndAddr.sin_port = dstPort;
 	sndAddr.sin_addr = dstIP;
-	sendto (udpSocket, "\0\0\0\0DSTREQ UDP hole punching", 28, 0,
+	sendto (udpSocket, DSTREQ, 5, 0,
 		(struct sockaddr *)&sndAddr, sizeof(sndAddr));
 }
 
@@ -334,6 +338,7 @@ int main(int argc, const char **argv)
 	Connected = FALSE;
 	DSTREQcnt = 0;
 	DVwait = FALSE;
+	AckSW = FALSE;
 	KeepAliveCnt = 0;
 	NodeVendorID =  VendorID;
 	NodeProductID = ProductID;
@@ -549,13 +554,18 @@ int main(int argc, const char **argv)
                         		{
 						if (!Connected && !memcmp(&SndPacketIdSave, &reqConMsg.ackConnect.PacketID, 2))
 						{
+							logfile = fopen	(LOGFILE, "a");
+							now = time(NULL);
+							fprintf (logfile, "24.24s Receive Ack\n", ctime(&now));
+							fclose (logfile);
 							dstPort = reqConMsg.ackConnect.port;
 							dstIP = reqConMsg.ackConnect.ip;
                         				sndAddr.sin_family = PF_INET;
                         				sndAddr.sin_port = dstPort;
                         				sndAddr.sin_addr = dstIP;
 							respFlags = RespNULL;
-                        				sendto (udpSocket, "\0\0\0\0SRCREQ UDP hole punching", 28, 0,
+							AckSW = TRUE;
+                        				sendto (udpSocket, SRCREQ, 5, 0,
                                 				(struct sockaddr *)&sndAddr, sizeof(sndAddr));
 						}
                         		}
